#
# Cookbook Name:: kosmos-mastodon
# Recipe:: nginx
#
# The MIT License (MIT)
#
# Copyright:: 2019, Kosmos Developers
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
# THE SOFTWARE.

mastodon_path = node["kosmos-mastodon"]["directory"]
server_name   = node["kosmos-mastodon"]["server_name"]

include_recipe "kosmos-nginx"

directory "#{node['nginx']['dir']}/snippets" do
  action :create
  owner 'www-data'
  mode 0640
end

template "#{node['nginx']['dir']}/snippets/mastodon.conf" do
  source 'nginx_conf_shared.erb'
  owner 'www-data'
  mode 0640
  variables streaming_port: node["kosmos-mastodon"]["streaming_port"],
            puma_port:      node["kosmos-mastodon"]["puma_port"],
            mastodon_path:  mastodon_path
  notifies :reload, 'service[nginx]', :delayed
end

template "#{node['nginx']['dir']}/sites-available/#{server_name}" do
  source 'nginx_conf_mastodon.erb'
  owner 'www-data'
  mode 0640
  variables server_name:         server_name,
            ssl_cert:            "/etc/letsencrypt/live/#{server_name}/fullchain.pem",
            ssl_key:             "/etc/letsencrypt/live/#{server_name}/privkey.pem",
            shared_config_path:  "#{node['nginx']['dir']}/snippets/mastodon.conf",
            onion_address:       File.read("/var/lib/tor/mastodon/hostname").strip
  notifies :reload, 'service[nginx]', :delayed
end

# Legacy vhost
nginx_site "mastodon" do
  action :disable
end

nginx_site server_name do
  action :enable
end

nginx_certbot_site server_name

#
# Tor hidden service
#
# The attributes for the hidden service are set in attributes/default.rb, due
# to the way the tor-full cookbook builds the path to the hidden service dir
include_recipe "tor-full"
